#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_GE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_GE_HPP_INCLUDED

#include <boost/simd/operator/include/functions/ge.hpp>

#endif
